@@ -1,35 +1,35 @@
 OC.L10N.register(
     "contacts",
     {
-    "All contacts" : "Todos los contactos",
     "Details" : "Detalles",
+    "All contacts" : "Todos los contactos",
     "Contacts" : "Contactos",
-    "Invalid image" : "Imagen inválida",
-    "Name" : "Nombre",
-    "Title" : "Título",
+    "Loading contacts …" : "Cargando contactos ...",
     "Download" : "Descargar",
-    "Delete" : "Borrar",
-    "Cancel" : "Cancelar",
-    "Address book" : "Libreta de direcciones",
     "Groups" : "Grupos",
-    "New contact" : "Nuevo contacto",
-    "No results" : "No hay resultados",
-    "Last modified" : "Última modificación",
+    "Group name" : "Nombre del grupo",
     "Rename" : "Renombrar",
     "Enabled" : "Habilitado",
-    "Disabled" : "Deshabilitado",
+    "Delete" : "Borrar",
     "Copy link" : "Copiar liga",
     "Share with users or groups" : "Compartir con otros usuarios o grupos",
     "can edit" : "puede editar",
-    "Address book name" : "Nombre de la libreta de direcciones",
     "First name" : "Nombre",
     "Last name" : "Apellido",
     "Display name" : "Nombre a desplegar",
-    "Group name" : "Nombre del grupo",
-    "Loading contacts …" : "Cargando contactos ...",
-    "Not grouped" : "No agrupado",
+    "Last modified" : "Última modificación",
+    "Invalid image" : "Imagen inválida",
+    "Name" : "Nombre",
+    "Title" : "Título",
+    "Cancel" : "Cancelar",
+    "Address book" : "Libreta de direcciones",
+    "New contact" : "Nuevo contacto",
+    "No results" : "No hay resultados",
     "Close" : "Cerrar",
     "Import" : "Importar",
+    "Not grouped" : "No agrupado",
+    "Email" : "Correo electrónico",
+    "Contact" : "Contacto",
     "Nickname" : "Apodo",
     "Detailed name" : "Nombre detallado",
     "Additional names" : "Nombres adicionales",
@@ -51,7 +51,6 @@ OC.L10N.register(
     "Birthday" : "Fecha de nacimiento",
     "Anniversary" : "Aniversario",
     "Date of death" : "Fecha de defunción",
-    "Email" : "Correo electrónico",
     "Instant messaging" : "Mensajería instantánea",
     "Phone" : "Teléfono fijo",
     "Mobile" : "Teléfono móvil",
@@ -76,7 +75,6 @@ OC.L10N.register(
     "Colleague" : "Colega",
     "Manager" : "Gerente",
     "Assistant" : "Asistente",
-    "Contact" : "Contacto",
     "Agent" : "Agente",
     "Emergency" : "Emergencia",
     "Co-worker" : "Compañero de trabajo",
@@ -84,7 +82,6 @@ OC.L10N.register(
     "Female" : "Femenino",
     "Male" : "Masculino",
     "None" : "Ninguno",
-    "Unknown" : "Desconocido",
-    "Timezone" : "Zona horaria"
+    "Unknown" : "Desconocido"
 },
 "nplurals=2; plural=(n != 1);");
