@@ -5,7 +5,7 @@ OC.L10N.register(
     "All contacts" : "所有聯絡人",
     "Contacts" : "通訊錄",
     "A contacts app for Nextcloud" : "Nextcloud 的通訊錄應用程式",
-    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextcloud 通訊錄應用程式是 Nextcloud 的 CardDAV 伺服器的用戶界介面。可輕鬆使用您的 Nextcloud 同步各個裝置上的聯絡人，並在線上編輯。\n\n* 🚀 **與其他 Nextcloud 應用程式整合！** 目前有電子郵件與日曆，還會有更多。\n* 🎉 **不會忘記生日！** 您可以將生日與其他重複的活動與您的 Nextcloud 日曆同步。\n* 👥 **分享通訊錄！** 您想與您的朋友或同事分享您的聯絡人嗎？沒問題！\n* 🙈 **我們沒有無謂地重複開發！** 以超棒且開放的 SabreDAV 函式庫為基礎。",
+    "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "Nextcloud 通訊錄應用程式是 Nextcloud 的 CardDAV 伺服器的用戶界面。可輕鬆使用您的 Nextcloud 同步各個裝置上的聯絡人，並在線上編輯。\n\n* 🚀 **與其他 Nextcloud 應用程式整合！** 目前有電子郵件與日曆，還會有更多。\n* 🎉 **不會忘記生日！** 您可以將生日與其他重複的活動與您的 Nextcloud 日曆同步。\n* 👥 **分享通訊錄！** 您想與您的朋友或同事分享您的聯絡人嗎？沒問題！\n* 🙈 **我們沒有無謂地重複開發！** 以超棒且開放的 SabreDAV 函式庫為基礎。",
     "Copy to full name" : "複製到全名",
     "Omit year" : "省略年份",
     "Allow updating avatars from social media" : "允許從社群媒體更新大頭照",
@@ -25,6 +25,7 @@ OC.L10N.register(
     "Leave circle" : "離開社交圈子",
     "Delete circle" : "刪除社交圈子",
     "Download" : "下載",
+    "Send email" : "傳送電郵",
     "Groups" : "群組",
     "Create a new group" : "建立新群組",
     "Group name" : "群組名稱",
@@ -39,7 +40,6 @@ OC.L10N.register(
     "An error happened during the creation of the circle" : "創建社交圈子的過程中發生錯誤",
     "Rename" : "重新命名",
     "Enabled" : "已啟用",
-    "Disabled" : "已停用",
     "Delete" : "刪除",
     "Copied" : "已複製",
     "Cannot copy" : "無法複製",
@@ -263,8 +263,6 @@ OC.L10N.register(
     "Some circle(s) an error occurred. Check the console for more details." : "某些圈子出錯，請查看控制台以獲取更多詳細信息。",
     "Unable to create circle {circleName}" : "無法創建社交圈子 {circleName}",
     "Unable to delete circle {circleId}" : "無法刪除社交圈子 {circleId}",
-    "Unable to delete contact" : "無法刪除聯絡人",
-    "Your web browser is out of date" : "您的網路瀏覽器已過期",
-    "This application is not compatible with Internet Explorer" : "此應用程式與 Internet Explorer 不相容"
+    "Unable to delete contact" : "無法刪除聯絡人"
 },
 "nplurals=1; plural=0;");
