@@ -58,7 +58,8 @@ class SocialApiService {
 	private $davBackend;
 	/** @var ITimeFactory */
 	private $timeFactory;
-
+	/** @var ImageResizer */
+	private $imageResizer;
 
 	public function __construct(
 					CompositeSocialProvider $socialProvider,
@@ -68,7 +69,8 @@ class SocialApiService {
 					IL10N $l10n,
 					IURLGenerator $urlGen,
 					CardDavBackend $davBackend,
-					ITimeFactory $timeFactory) {
+					ITimeFactory $timeFactory,
+					ImageResizer $imageResizer) {
 		$this->appName = Application::APP_ID;
 		$this->socialProvider = $socialProvider;
 		$this->manager = $manager;
@@ -78,6 +80,7 @@ class SocialApiService {
 		$this->urlGen = $urlGen;
 		$this->davBackend = $davBackend;
 		$this->timeFactory = $timeFactory;
+		$this->imageResizer = $imageResizer;
 	}
 
 
@@ -223,6 +226,16 @@ class SocialApiService {
 				return new JSONResponse([], Http::STATUS_NOT_FOUND);
 			}
 
+			if (is_resource($socialdata)) {
+				$socialdata = stream_get_contents($socialdata);
+			}
+
+			$socialdata = $this->imageResizer->resizeImage($socialdata);
+
+			if (!$socialdata) {
+				return new JSONResponse([], Http::STATUS_INTERNAL_SERVER_ERROR);
+			}
+
 			// update contact
 			$changes = [];
 			$changes['URI'] = $contact['URI'];
